@@ -21,14 +21,14 @@
 
 #include <errno.h>
 
-const char* FILE_NAME = "Sys/Select.c";
+static const char* FILE_NAME = "Sys/Select.c";
 
 int32_t SPVM__Sys__Select__FD_ZERO(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_set = stack[0].oval;
   
   if (!obj_set) {
-    return env->die(env, stack, "$set must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The fd_set data structure $set must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   fd_set* set = env->get_pointer(env, stack, obj_set);
@@ -43,17 +43,17 @@ int32_t SPVM__Sys__Select__FD_SET(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t fd = stack[0].ival;
   
   if (!(fd >= 0)) {
-    return env->die(env, stack, "$fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(fd <= FD_SETSIZE)) {
-    return env->die(env, stack, "$fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_set = stack[1].oval;
   
   if (!obj_set) {
-    return env->die(env, stack, "$set must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The fd_set data structure $set must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   fd_set* set = env->get_pointer(env, stack, obj_set);
@@ -68,17 +68,17 @@ int32_t SPVM__Sys__Select__FD_CLR(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t fd = stack[0].ival;
   
   if (!(fd >= 0)) {
-    return env->die(env, stack, "$fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(fd <= FD_SETSIZE)) {
-    return env->die(env, stack, "$fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_set = stack[1].oval;
   
   if (!obj_set) {
-    return env->die(env, stack, "$set must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The fd_set data structure $set must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   fd_set* set = env->get_pointer(env, stack, obj_set);
@@ -93,17 +93,17 @@ int32_t SPVM__Sys__Select__FD_ISSET(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t fd = stack[0].ival;
   
   if (!(fd >= 0)) {
-    return env->die(env, stack, "$fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(fd <= FD_SETSIZE)) {
-    return env->die(env, stack, "$fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_set = stack[1].oval;
   
   if (!obj_set) {
-    return env->die(env, stack, "$set must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The fd_set data structure $set must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   fd_set* set = env->get_pointer(env, stack, obj_set);
@@ -119,10 +119,10 @@ int32_t SPVM__Sys__Select__select(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = stack[0].ival;
   if (!(fd >= 0)) {
-    return env->die(env, stack, "$fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   if (!(fd <= FD_SETSIZE)) {
-    return env->die(env, stack, "$fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file descriptor $fd must be less than FD_SETSIZE.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_readfds = stack[1].oval;
@@ -152,7 +152,7 @@ int32_t SPVM__Sys__Select__select(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t updated_fds_count = select(fd, readfds, writefds, exceptfds, timeout);
   
   if (updated_fds_count == -1) {
-    env->die(env, stack, "[System Error]select failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]select() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
